@@ -8,6 +8,9 @@
 #include "imgur-service-glue.h"
 #include "upload.h"
 #include "parse.h"
+#include "prefs.h"
+#include "recording.h"
+#include "list-records.h"
 
 #define G_IMGUR_ERROR g_imgur_error_quark ()
 GQuark
@@ -60,6 +63,12 @@ imgur_upload_init (ImgurUpload *iu)
       g_error_free (error);
     }
 
+  if (!dbus_g_proxy_call (proxy, "RequestName", &error,
+        G_TYPE_STRING, "com.imgur", G_TYPE_UINT, 0,
+        G_TYPE_INVALID,
+        G_TYPE_UINT, &ret, G_TYPE_INVALID))
+    g_error ("Failed to request name: %s", error->message);
+ 
   g_object_unref (proxy);
 
 }
@@ -105,6 +114,7 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
   gchar *message = NULL;
   GList *parsed, *cursor;
   gchar *temp = NULL;
+  ImgurPrefs *prefs = imgur_prefs_new ();
 
   *error = NULL;
 
@@ -113,7 +123,7 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
       filename += 5;
     }
 
-  upload (filename, &success, &message, NULL);
+  upload (prefs, filename, &success, &message, NULL);
 
   if (!success)
     {
@@ -128,6 +138,7 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
                     "%s", message);
 
        g_free (message);
+       g_free (prefs);
 
        return FALSE;
     }
@@ -153,8 +164,15 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
              }
           }
 
+       if (prefs->recording)
+       {
+         imgur_recording_store (*result,
+	        filename);
+       }
+
        g_list_free (parsed);
        g_free (message);
+       g_free (prefs);
 
        return TRUE;
     }
@@ -196,7 +214,8 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
 
        if (!message)
          {
-           message = g_strdup ("Error in hosting.");
+           message = g_strdup_printf ("Error in hosting: %d.",
+		code);
          }
 
        g_set_error (error,
@@ -206,11 +225,48 @@ imgur_service_upload (ImgurUpload *iu, gchar *filename, GHashTable **result, GEr
 
        g_list_free (parsed);
        g_free (message);
+       g_free (prefs);
 
        return FALSE;
     }
 }
 
+gboolean
+imgur_service_list_records (ImgurUpload *iu, gchar ***result, GError **error)
+{
+	*result = imgur_list_records ();
+	return TRUE;
+}
+
+gboolean
+imgur_service_get_record (ImgurUpload *iu, gchar *record, GHashTable **result, GError **error)
+{
+	gchar *last_dot = strrchr (record, '.');
+	gchar *last_slash = strrchr (record, '/');
+	gchar *temp = NULL;
+
+	/*
+ 	 * Record IDs can be represented as filenames;
+	 * if we get one of these, it must be canonicalised
+	 * by removing the path and the extension.
+	 */
+
+	if (last_slash)
+		record = last_slash+1;
+
+	if (last_dot && last_dot > last_slash)
+	{
+		temp = g_strndup (record,
+			last_dot - record);
+	}
+
+	*result = imgur_get_record (temp? temp: record);
+
+	g_free (temp);
+
+	return TRUE;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -219,7 +275,6 @@ main (int argc, char **argv)
   DBusGConnection *bus;
   DBusGProxy *bus_proxy;
   ImgurUpload *uploader;
-  int request_name_result;
 
   g_type_init ();
 
@@ -238,19 +293,9 @@ main (int argc, char **argv)
   bus_proxy = dbus_g_proxy_new_for_name (bus, "org.freedesktop.DBus",
                 "/org/freedesktop/DBus", "org.freedesktop.DBus");
 
-  if (!dbus_g_proxy_call (bus_proxy, "RequestName", &error,
-        G_TYPE_STRING, "com.imgur", G_TYPE_UINT, 0,
-        G_TYPE_INVALID,
-        G_TYPE_UINT, &request_name_result, G_TYPE_INVALID))
-    g_error ("Failed to request name: %s", error->message);
-
   uploader = g_object_new (IMGUR_TYPE_UPLOAD,
                            NULL);
 
-  dbus_g_connection_register_g_object (bus,
-                                       "/com/imgur",
-                                       G_OBJECT (uploader));
-
   g_main_loop_run (mainloop);
 
 }
