@@ -23,11 +23,8 @@
 #include <glib.h>
 #include <curl/curl.h>
 
-#include "prefs.h"
-
 void
-upload (ImgurPrefs *prefs,
-	gchar *filename,
+upload (gchar *filename,
 	gboolean *success,
 	gchar **result,
 	gboolean (*progress)(char));
